function love.load()
	-- Fullscreen
	success = love.window.setFullscreen( true )
	-- Getting a window size just in case
	width = love.graphics.getWidth()
	height =  love.graphics.getHeight()
	-- Font
	monaco = love.graphics.newFont( "resources/monaco.ttf", 64 )
	monacoSmall = love.graphics.newFont( "resources/monaco.ttf", 32 )
	-- Tiles and characters
	tileW, tileH = 16, 16
	citytiles = love.graphics.newImage( "resources/citytileset.png" )
	tilesetW, tilesetH = citytiles:getWidth(), citytiles:getHeight()
	maxTiles = ((citytiles:getWidth()*citytiles:getHeight())/16)
	cityBatch = love.graphics.newSpriteBatch( citytiles, 10000 )
	-- Background
	backgroundTile = love.graphics.newImage("resources/backgroundTile.png")
	backgroundTile:setWrap( "repeat", "repeat")
	background = love.graphics.newQuad( 0, 0, width, height, 64, 64 )
	-- Current version
	Version = love.graphics.newText( monaco, "Testing generator v 0.1a")
	-- Modules
	cityGenerator = require ("cityGenerator")
	menu = require ("menu")
	-- Initializing gamestate variables
	gamestate = "menu"
	herochosen = false
	hero = "none"
	-- Custom cursor
	cursorData = love.image.newImageData( "resources/cursor.png" )
	cursor = love.mouse.newCursor( cursorData, 4, 2 )
	love.mouse.setCursor( cursor )
	-- Creating a table holding the tiles
	quads = {}
	quads[0] = love.graphics.newQuad( 0, 48, tileW, tileH, tilesetW, tilesetH) -- камень левый *0*
	quads[1] = love.graphics.newQuad( 16, 48, tileW, tileH, tilesetW, tilesetH) -- камень *1*
	quads[2] = love.graphics.newQuad( 16, 48, tileW, tileH, tilesetW, tilesetH) -- камень правый *2*
	quads[3] = love.graphics.newQuad( 0, 0, tileW, tileH, tilesetW, tilesetH) -- верхний левый *3*
	quads[4] = love.graphics.newQuad( 16, 0, tileW, tileH, tilesetW, tilesetH) -- верхний *4*
	quads[5] = love.graphics.newQuad( 32, 0, tileW, tileH, tilesetW, tilesetH) -- верхний правый*5*
	quads[6] = love.graphics.newQuad( 0, 16, tileW, tileH, tilesetW, tilesetH) -- средний левый *6*
	quads[7] = love.graphics.newQuad( 16, 16, tileW, tileH, tilesetW, tilesetH) -- средний *7*
	quads[8] = love.graphics.newQuad( 32, 16, tileW, tileH, tilesetW, tilesetH) -- средний правый *8*
	quads[9] = love.graphics.newQuad( 0, 32, tileW, tileH, tilesetW, tilesetH) -- нижний левый *9*
	quads[10] = love.graphics.newQuad( 16, 32, tileW, tileH, tilesetW, tilesetH) -- нижний *10*
	quads[11] = love.graphics.newQuad( 32, 32, tileW, tileH, tilesetW, tilesetH) -- нижний правый *11*
	quads[12] = love.graphics.newQuad( 0, 64, tileW, tileH, tilesetW, tilesetH) -- синий дом *12*
	quads[13] = love.graphics.newQuad( 16, 64, tileW, tileH, tilesetW, tilesetH) -- красный дом *13*
	quads[14] = love.graphics.newQuad( 32, 64, tileW, tileH, tilesetW, tilesetH) -- дорога *14*
	-- Generating a starting city
	cityGenerator.generateCity()
	updateBatch()
end

function love.update(dt)
	if hero ~= "none" then
		herochosen = true
	else
		herochosen = false
	end
end
	
function love.draw()
	if gamestate == "playing" then
		if herochosen == true then
			textPos = (#city*8) - (Version:getWidth()/2) + 16
			love.graphics.draw(Version, textPos, (#city+1)*16)
			love.graphics.draw(cityBatch)
			-- Drawing a raw matrix to check if it generates properly
			--[[
			for y = 1, #city do
				for x = 1, #city do
					text1 = love.graphics.newText(font, tostring(city[x][y]))
					love.graphics.draw(text1, x*24, y*24)
				end
			end
			]]--
		elseif herochosen == false then
			love.graphics.draw( backgroundTile, background, 0, 0)
			menu.drawHero( "beard", width/2 - 200, height/2, 4 )
			menu.drawHero( "smoker", width/2, height/2, 4 )
			menu.drawHero( "trump", width/2 + 200, height/2, 4 )
		end
	end

	if gamestate == "menu" then
		love.graphics.draw( backgroundTile, background, 0, 0)
		menu.drawButton("start", width/2, 300 )
		menu.drawButton("chooseHero", width/2, 500)
		menu.drawButton("options", width/2, 800)
	end
	-- DEBUG
	love.graphics.print( hero, 100, 100 )
	love.graphics.print( gamestate, 100, 200 )
	love.graphics.print( tostring(herochosen), 100, 300 )
end

function love.keypressed(key)
	-- Menu state
	if gamestate == "menu" then
   		if key == "escape" then
      		love.event.quit()
   		end
   	end
   	
   	-- Playing state
   	if gamestate == "playing" then
   		if key == "return" then
   			cityGenerator.generateCity()
   			updateBatch()
   		elseif key == "escape" then
      		gamestate = "menu"
      	elseif key == "r" then
      		resetHero()
   		end
   	end
end

function love.mousepressed( x, y, button, istouch )
	if gamestate == "menu" then
		for key, value in pairs(buttons["mouseOver"]) do
	  		if buttons["mouseOver"][key] and button == 1 then
	  			menu.useButton(buttons["name"][key])
	  		end
		end
	end

	for key, value in pairs(heroes["mouseOver"]) do
  		if heroes["mouseOver"][key] and button == 1 then
  			menu.setHero(heroes["hero"][key]) 
  		end
	end
end

function updateBatch()
  cityBatch:clear()
  for x=1, citySize+1 do
    for y=1, citySize+1 do 
    	spritenumber = city[x][y]
		cityBatch:add(quads[spritenumber], x*tileW, y*tileH)
    end
  end
  cityBatch:flush()
end

function resetHero()
	herochosen = false
	hero = "none"
end